@@ -1,18 +1,13 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * m_pedit.c		generic packet editor actions module
  *
- *		This program is free software; you can distribute it and/or
- *		modify it under the terms of the GNU General Public License
- *		as published by the Free Software Foundation; either version
- *		2 of the License, or (at your option) any later version.
- *
  * Authors:  J Hadi Salim (hadi@cyberus.ca)
  *
  * TODO:
  *	1) Big endian broken in some spots
  *	2) A lot of this stuff was added on the fly; get a big double-double
  *	and clean it up at some point.
- *
  */
 
 #include <stdio.h>
